bayespy.inference.vmp.nodes.gaussian.GaussianGammaToGaussianWishart.has_plotter
===============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaToGaussianWishart.has_plotter